package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````N!L``#0```#4H0````0`!30`(``)
M`"@`'0`<``$``'!\D0``?)$``'R1``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!HD@``:)(```4`````$```
M`0```*"=``"@K0``H*T``*@"``"\`@``!@`````0```"````J)T``*BM``"H
MK0``(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DH)T`
M`*"M``"@K0``8`(``&`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`:E=0#8A/M[VTL<)]`*ZM#VE/?B0$
M````$`````$```!'3E4```````,````"`````````&$```!L````````````
M``!:````0@``````````````"````````````````````#H`````````2P``
M`#D```!E`````````"P```!1````4@```#,```!B````:`````,````P````
M```````````C````1P```"X``````````````%,```!*````-P```$X```!?
M````:P```"$````'````"0`````````8`````````$````!C````4````#0`
M````````30```&0````V````#0```#L``````````````%L````R````20``
M`$8````J````````````````````/@```$0````````````````````6````
M#P`````````_````(@```"<```````````````H```!(````.````#P```!5
M`````````"\```!J````00````````````````````````!6`````````$,`
M``!8````*`````8````D````3```````````````````````````````````
M````````````````````````````````````````````````````````````
M$`````````!7````````````````````````````````````%```````````
M````60`````````<`````````&8```!I`````````!\``````````````!D`
M````````9P```````````````````!L````.````(````"8````$````#```
M`!X````M```````````````=````3P``````````````5````"4```!=````
M&@```"L````7````"P```````````````````%P````Q````/0```!,```!%
M````7@````````````````````````````````````4`````````````````
M```U````````````````````$0```````````````````"D````5````````
M`!(`````````````````````````8````````````````````&$`````````
M`````!$```!.````"`````@````!D!`$)4`$@"B```6@AE"$@($``@LH!(PX
M@!)!B@``"$X```!/````4@```%8```!7````8````&$```!B`````````&0`
M``!E````9@```&<```!H````:P```````````````:\TZ&[%WQ_.WD<M:W^:
M?"[%F[;49-1\=E0\E"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=Y
MNN.2?/JA;&"93\.;:PE#UF>OS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@
MIP(*:AJ>4+_:5QNCX/M)``````````````````````````#T%0````````,`
M#````````+`````````#`!@`&@(`````````````$@```+X"````````````
M`!(```!G```````````````2````R```````````````$@````4"````````
M`````!(```!6`@`````````````2````I0(`````````````$@```'\`````
M`````````!(```#Y`@`````````````2`````0``````````````(````+(!
M`````````````!(```#P`@`````````````2````1@(`````````````$@``
M`#D#`````````````!(```!-`0`````````````2````S@$`````````````
M$@```!```````````````"````#6`@`````````````2````#`(`````````
M````$@```,,"`````````````!(``````@`````````````2````P0``````
M````````$@```"P``````````````"````"Z```````````````2````I0$`
M````````````$@```,@"`````````````!(````Q`0`````````````6````
M(0$`````````````$@````P#`````````````!(````0`0`````````````2
M````X0(`````````````$@```-H``````````````!(```#O````````````
M```2````U@$`````````````$@````D$`````````````!(```!B`0``````
M```````2````L0``````````````$0```#\"`````````````!(```!``P``
M```````````1````W0$`````````````$@```!,"`````````````!(```"P
M`@`````````````2````]@``````````````$@```+D!`````````````!(`
M``!W`@`````````````2````^`$`````````````$@```)X"````````````
M`!(```"6```````````````2````,0(`````````````$@```,`!````````
M`````!(```#_```````````````2````N0``````````````$@```&T`````
M`````````!(```!B`@`````````````2````G@$`````````````$@```)("
M`````````````!(```!$`0`````````````2````KP``````````````$0``
M`/$!`````````````!$````=`P`````````````1````T```````````````
M$@```"H#`````````````!$```#A```````````````2````IP``````````
M````$@````4!`````````````!(```"(`0`````````````2````E@$`````
M````````$@```(,"`````````````!(```!&```````````````2````<0$`
M````````````$@```%L!`````````````!(```#'`0`````````````2````
M[`$`````````````$@```"`"`````````````!(```!8```````````````B
M````9`0``%RP````````$``9`!($``"\2@``/`$``!(`#@")!```F$```%`'
M```2``X`4P```/`8``#(`@``$@`.`(D#``!T,@``!````!(`#@"G`P``Z$<`
M`-0"```2``X`.@0``$BP````````$``9`*\$``!X,@``D`(``!(`#@!O!```
M2+`````````0`!D`F@,```@U```P````$@`.`+T#```D/```H````!(`#@`>
M!```0$\```0````1`!``2`0``(!,``!4`0``$@`.`%,$```(,0``5````!(`
M#@!;!```7+`````````0`!D`A`0``%RP````````$``9`)T$```@/P``>`$`
M`!(`#@#&!```Q#P``'0````2``X`+00```"P````````$``8`.$#```X-0``
MJ`$``!(`#@"6!```2+`````````0`!@`O`0``$2P```$````$0`8`#,$``"X
M&P```````!(`#@![!```^$L``(@````2``X`+P0```"P````````(``8`/<#
M``#\/@``)````!(`#@#+`P``7#$``!@!```2``X`[0,``-1-``!0`0``$@`.
M`&,$``!<L````````!``&0#.!```X#8``$0%```2``X``%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE
M`&%B;W)T`%]?<F5G:7-T97)?871F;W)K`%]?865A8FE?=6YW:6YD7V-P<%]P
M<C``7U]S=&%C:U]C:&M?9F%I;`!S=')N8VUP`%]?96YV:7)O;@!L<W1A=#8T
M`&%C8V5S<P!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H
M:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`4&5R;%]N97=84P!097)L7VYE=UA3
M7V9L86=S`&)O;W1?1'EN84QO861E<@!03%]C=7)R96YT7V-O;G1E>'0`<F5A
M9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]A
M96%B:5]U;G=I;F1?8W!P7W!R,0!?7VUE;6UO=F5?8VAK`')E86QL;V,`9V5T
M<&ED`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``
M<W1R<F-H<@!M96UC<'D`7U]V9G!R:6YT9E]C:&L`97AI=`!S=&1E<G(`;'-E
M96LV-`!R96%D`&UE;6-M<`!G971U:60`<W1R<W1R`&UK9&ER`%]?97)R;F]?
M;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E
M`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A
M;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U;@!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``4$Q?;65M;W)Y7W=R
M87``;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\`;&EB8RYS
M;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`;&EB9V-C7W,N<V\N,0!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`
M<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA
M;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C
M;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7V)S<U]S=&%R
M=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?8G-S7V5N9%]?`%]?
M8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D
M:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'0T-?,RXU`$=,24)#7S(N,S0`
M1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U+C,X+C(O87)M=C=L+6QI;G5X
M+71H<F5A9"UM=6QT:2TV-&EN="]#3U)%``````````(``0`"``(``@`!``$`
M`P`!``$``@`!``$``@`!``(``0`!``(``@`"``(``0`$``(``0`!``$``0`!
M``$``@`"``(``@`!``(``@`%``(``@`!``(``@`!``(``@`"``(``@`"``0`
M`@`!``(``0`"``(``@`!``(``0`"``(``0`"``(``0`&``,``@`"``(``@`"
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!`````0`!`&<#```0````(````!1I:0T```4`VP0`
M```````!``$`>P,``!`````@````529Y"P```P#E!`````````$``P!=`P``
M$`````````"TD98&```&`.T$```0````LY&6!@``!`#X!```$````!1I:0T`
M``(`VP0```````"@K0``%P```*2M```7````_*\``!<````$L```%P```!2P
M```7````&+```!<````@L```%P```"2P```7````*+```!<````LL```%P``
M`#"P```7````.+```!<````\L```%P```$2P```7````R*\``!4+``#,KP``
M%0P``-"O```5$P``U*\``!49``#8KP``$QT``-RO```5'@``X*\``!4?``#D
MKP``%2<``.BO```5*0``[*\``!4]``#PKP``%3X``/2O```50```^*\``!5-
M``#4K@``%@,``-BN```6!```W*X``!8%``#@K@``%@8``.2N```6!P``Z*X`
M`!8(``#LK@``%@D``/"N```6#```]*X``!8-``#XK@``%@X``/RN```6#P``
M`*\``!80```$KP``%A$```BO```6$@``#*\``!84```0KP``%A4``!2O```6
M%@``&*\``!87```<KP``%A@``""O```6&@``)*\``!8;```HKP``%AP``"RO
M```6(```,*\``!8A```TKP``%B(``#BO```6(P``/*\``!8D``!`KP``%B4`
M`$2O```6)@``2*\``!8H``!,KP``%BH``%"O```6*P``5*\``!8L``!8KP``
M%BT``%RO```6+@``8*\``!8O``!DKP``%C```&BO```6,0``;*\``!8R``!P
MKP``%C,``'2O```6-```>*\``!8U``!\KP``%C8``("O```6-P``A*\``!8X
M``"(KP``%CD``(RO```6.@``D*\``!8[``"4KP``%C\``)BO```600``G*\`
M`!9"``"@KP``%D,``*2O```61```J*\``!9%``"LKP``%D8``+"O```61P``
MM*\``!9)``"XKP``%DH``+RO```62P``P*\``!9,``#$KP``%DT```A`+>E_
M`0#K"("]Z`3@+>4$X)_E#N"/X`CPON6XF````,:/X@G*C.*X^+SE`,:/X@G*
MC.*P^+SE`,:/X@G*C.*H^+SE`,:/X@G*C.*@^+SE`,:/X@G*C.*8^+SE`,:/
MX@G*C.*0^+SE`,:/X@G*C.*(^+SE`,:/X@G*C.*`^+SE`,:/X@G*C.)X^+SE
M`,:/X@G*C.)P^+SE`,:/X@G*C.)H^+SE`,:/X@G*C.)@^+SE`,:/X@G*C.)8
M^+SE`,:/X@G*C.)0^+SE`,:/X@G*C.)(^+SE`,:/X@G*C.)`^+SE`,:/X@G*
MC.(X^+SE`,:/X@G*C.(P^+SE`,:/X@G*C.(H^+SE`,:/X@G*C.(@^+SE`,:/
MX@G*C.(8^+SE`,:/X@G*C.(0^+SE`,:/X@G*C.((^+SE`,:/X@G*C.(`^+SE
M`,:/X@G*C.+X][SE`,:/X@G*C.+P][SE`,:/X@G*C.+H][SE`,:/X@G*C.+@
M][SE`,:/X@G*C.+8][SE`,:/X@G*C.+0][SE`,:/X@G*C.+(][SE`,:/X@G*
MC.+`][SE`,:/X@G*C.*X][SE`,:/X@G*C.*P][SE`,:/X@G*C.*H][SE`,:/
MX@G*C.*@][SE`,:/X@G*C.*8][SE`,:/X@G*C.*0][SE`,:/X@G*C.*(][SE
M`,:/X@G*C.*`][SE`,:/X@G*C.)X][SE`,:/X@G*C.)P][SE`,:/X@G*C.)H
M][SE`,:/X@G*C.)@][SE`,:/X@G*C.)8][SE`,:/X@G*C.)0][SE`,:/X@G*
MC.)(][SE`,:/X@G*C.)`][SE`,:/X@G*C.(X][SE`,:/X@G*C.(P][SE`,:/
MX@G*C.(H][SE`,:/X@G*C.(@][SE`,:/X@G*C.(8][SE`,:/X@G*C.(0][SE
M`,:/X@G*C.((][SE`,:/X@G*C.(`][SE`,:/X@G*C.+X]KSE`,:/X@G*C.+P
M]KSE`,:/X@G*C.+H]KSE`,:/X@G*C.+@]KSE`,:/X@G*C.+8]KSE`<J@XW!`
M+>D,P$W@R`^,Y5C"G^4HT$WB5#*?Y1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-
MXA0@C>(<`(WB-%*?Y0`PD^4D,(WE`#"@X];__^LD(I_E!5"/X`(@E><<,I_E
M#""-Y0,PE><"$*#A`P"@X1`PC>5N#0#K!#*?Y0,PE><`0-/E``!4XT\```IP
M+QWN\#&?Y1P`G>4#,)_G`T"`X@,@DN<$`(#BSC/2Y0<!<.,#,(/CSC/"Y6``
M`(H``:#AH?__ZP`PH.&\(9_E&!"=Y0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=
MY0``D>4,P(_@!5"/X`[@C^`!`%+C84"#Z`0PC.54``#:!`!!X@S`@^("`8#@
M!."QY0$`4.$$X*SE^___&@/`@N(`X*#C:%&?Y6@1G^4%4(_@#`"5Y00@H.$`
MX(WE`1"/X`SA@^<&___K``!0XRD```I$49_E(&"-X@50C^`,`)7E3?__ZP!`
MH.$P`9_E!A"@X0``C^#2`P#K``!0XR````H<,9_E`S"/X`P`D^7E_O_K(/__
MZPPAG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB
M<("]Z/[^_^O<()_E``!0XP(@C^`,`(+E'P``"A/__^MP+QWNQ#"?Y0,PG^<#
M,)+GKD;#Y:/__^H,`)7EX?[_Z]+__^H(`)7E``!0XP$```KK"P#KV?__ZI0`
MG^4&$*#A``"/X*8#`.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)7G``"/
MX`,0H.$,,(WE-?__ZP3`H..P___J`0"@XUO__^L>___KJ)4``"`!``!\E0``
M``$``!@!```H`0``2)8``'R6``!HE@``"#D```@Y```@E@``H!(``/25```H
M-@``R)4``"R4``!\E0``\)0``!0U```L`0``[#8```"PH.,`X*#C!!"=Y`T@
MH.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<M___KC?[_
MZ]22```T`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!D_[_ZKR2```$`0``
M+`"?Y2PPG^4L()_E``"/X`,PC^```%/A`B"/X![_+P$8,)_E`S"2YP``4^,>
M_R\!$_\OX124```0E```B)(```@!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?
MH.$H()_E0Q&!X,$0L.$"((_@'O\O`1@PG^4#,)+G``!3XQ[_+P$3_R_AU),`
M`-"3```XD@``#`$``%@PG^58()_E`S"/X``PT^4"((_@``!3XQ[_+Q$!RJ#C
M$$`MZ0S`3>#X#XSE-#"?Y0,PDN<``%/C`@``"B@PG^4#`)_G^?[_Z\?__^L!
M(*#C&#"?Y0,PC^``(,/E$("]Z(23``#\D0``,`$```B3```XDP``S?__Z@``
M```!RJ#C\$\MZ0S`3>!`#8SE:"R?Y6@\G^4"((_@`S"2YZ??3>(`$*#A$,"-
MX@`PD^64,HWE`#"@XPP@H.$`0*#C0`"`XH!0@>)`0!#I+C2@X?\\`^(.=*#A
M+CR#X0@`@.+_>`?B#CR#X39OO^8',(/A!0!0X01`@N4`8(+E"#""Y0Q`@N40
M((+B[O__&H(_C.(<0)WE>,"=Y00PC>6(,)WE&%"-X@@0C>4%`*#A`Q"@X0R0
MH.%\()WE&+"=Y8"`G>6$<)WEC."=Y1!@G>44H)WE`$"-Y0Q0C>4!``#J!;"@
MX0!`C>4`0*#C`3"@X3S`D.4X$)#E"%"PY71`@.4$0)#E!1`AX`D0(>`$P"S@
M!A`AX`+`+.`*P"S@")"@X0.`H.&A/Z#AC#"#X0$0D>`#$('A!#"=Y0<@H.$`
M`%/A#G"@X0M@H.$`X*#C`*"=Y7`0@.7A__\:F3D'XP@0G>4,4)WE"`"1Y0`4
MD>@(0!7E#."1Y8(Z1>,0D)'E&+"1Y:HMH.$@`:#A*F&@X8PB@N$.#X#A#&^&
MX0C@D>4#P)3@($"1Y0MP*>`.#X#A&("=Y03`G.`.<`?@BB*"X0MP)^``X"G@
M#""2X`=`DN`*X`[@`R"8X`G@+N`+()+@"F^&X0[`DN`(()7E!N`@X`,@DN`$
MX`[@`.`NX`D@DN#DS8S@#B"2X.Q]@N`0()7E&."5Y0,@DN``()+@9`$FX`P`
M`.`&`"#@;,&@X0``DN`#X)[@!N">X&1A+.`'8`;@9&$FX.<-@.`&X)[@X&V.
MX"#@E>6A*P[C`^">X&3ACN!G02S@`$`$X`Q`).`$X)[@*$"5Y6`!H.$#0)3@
M#,"4X&=!(.`&0`3@9T$DX.;MCN`$P)S@[DV,X##`E>79+D;C`\"<X&?!C.!F
M<2#@#G`'X`!P)^`'P)S@.'"5Y6[AH.$#<)?@``"7X&9Q+N`$<`?@9G$GX.3-
MC.`'`)#@['V`X$``E>4#`)#@9@&`X&1A+N`,8`;@#F`FX`8`D.#G;8#@2`"5
MY6S!H.$#`)#@#@"0X&3A+.`'X`[@9.$NX`X`D.#F[8#@4`"5Y0,`D.!D`8#@
M9T$LX`9`!.`,0"3@!`"0X.Y-@.!8`)7E9F&@X0,`D.`,`)#@9\$FX`[`#.!G
MP2S@#`"0X.3-@.!@`)7E`P"0X&<!@.!N<2;@!'`'X`9P)^`'`)#@['V`X&@`
ME>5D0:#A`P"0X`8`D.!N823@#&`&X&YA)N`&`)#@YVV`X'``E>4#`)#@;@&`
MX&SA).`'X`[@!.`NX`X`D.#F[8#@>`"5Y6=QH.$#`)#@!`"0X&Q!)^`&0`3@
M;$$DX`0`D.#N38#@@`"5Y0,`D.!L`8#@9L$GX`[`#.`'P"S@#`"0X(C`E>5N
MX:#A`\"<X`?`G.!F<2[@!'`'X&9Q)^`'P)S@D'"5Y>0-@.`#,)?@9C&#X&1A
M+N``8`;@#F`FX`8PD^"88)7EX,V,X`)@EN!@`:#AH'"5Y0[@EN!D82#@#&`F
MX`;@GN`"8)?@[#V#X*APE>5D88;@;$$@X`-`).#C[8[@!&"6X&,QH.$"0)?@
M``"4X+!PE>5L02/@#D`DX`1`D.`"`)?@[FV&X&P!@.!NP2/@N'"5Y0;`+.`,
M`)#@9L&@X>9-A.#`@)7E`F"7X&YQ+.`$<"?@`V"6X.0-@.`'8);@`G"8X&[A
MA^#(@)7EX'V&X&1A+.``8";@!N">X&`!H.$"8)C@#,"6X-"`E>5D82#@!V`F
MX`9@G.`"P)C@Y^V.X-B`E>5DP8S@9T$@X`Y`).#N;8;@!,"<X&[AH.$"0)C@
M``"4X."`E>5G02[@!D`DX`1`D.#</`OC`@"8X.;-C.#H@)7E9P&`X&9Q+N`,
M<"?@[$V$X`<`D.!LP:#A`G"8X`YPE^#P@)7E^."5Y691+.`$4"7@Y`V`X`50
ME^#@?87@`H"8X&11+.!F88C@`%`EX`50EN!@`:#A`N">X!AAG>4,P)[@9.$@
MX`?@+N#G787@#L"<X`+@EN!DX8[@Y6V,X"!!G>5GP2#@!<`LX`S@GN!EP:#A
M`D"4X"A1G>4``)3@9T$LX`9`).`$0)#@`@"5X.;MCN!F42S@9P&`X#!QG>4.
M4"7@[DV$X`4`D.!NX:#A`E"7X`Q0E>`X<9WEY,V`X&8!+N`$`"#@``"5X`)0
ME^!F487@0'&=Y61A+N`,8";@[`V`X`90E>!LP:#A`F"7X`Y@EN!(<9WE9.$L
MX`#@+N#@787@#N"6X`(@E^!D(8+@4'&=Y>5-CN!@X2S@&S](XV5AH.$%X"[@
M#B"2X`-PE^!@X8;A8%$&X`S`E^`$X`[@6'&=Y07@CN$.X)S@`\"7X.0M@N!@
MP8S@9`&&X611!N!@<9WE`@``X.+MCN`%`(#A8B&@X611@N$,P)#@`P"7X`8`
MD.!H<9WE9&$"X`Y0!>`&4(7A[LV,X`!0E>`#<)?@;@&"X>QMA>!D08?@;E$"
MX'!QG>4,``#@;,&@X04`@.%N48SA>(&=Y00`D.`&4`7@`T"7X&YQ#.`"0)3@
M!U"%X010E>`#0)C@Y@V`X&Y!A.!FX8SA9G$,X("!G>4`X`[@!^".X>!=A>`$
M0)[@8`&@X0/@F.`,X)[@Y<V$X&9!@.%F<0#@B(&=Y05`!.`'0(3A#D"4X`/@
MF.!F88[@9>&`X65Q`."0@9WE#.`.X`?@CN'L383@!F">X&S!H.$#X)C@`.">
MX.0-AN!E88SA97$,X)B!G>4$8`;@!V"&X0[@EN`#8)C@96&&X&11C.%D<0S@
MH(&=Y0!0!>`'4(7AX.V.X`9@E>!@`:#A`U"8X`Q0E>#NS8;@9&&`X61Q`."H
M@9WE#F`&X`=@AN$%4);@`V"8X&1AAN!N08#A;G$`X+"!G>4,0`3@!T"$X>Q=
MA>`&8)3@;,&@X0-`F.``0)3@Y0V&X&YAC.%N<0S@N(&=Y05@!N`'8(;A!&"6
MX`-`F.!N083@9>&,X<"!G>5E<0S@`.`.X`?@CN'@;8;@!.">X&`!H.$#0)C@
M#,"4X&5!@.%E<0#@R(&=Y09`!.`'0(3A#$"4X`/`F.#F[8[@95&,X&;!@.%F
M<0#@#L`,X`?`C.$`<*#CUB$,X]"!G>7N383@!5"<X&[AH.$#P)C@`,"<X.0-
MA>!F48[AV(&=Y010!>`$<('E#'"!Y11P@>4<<('E9G$.X`=0A>$,4)7@`\"8
MX&9AC.!DP8[A9'$.X."!G>4`P`S@!\",X>!=A>`&P)S@8`&@X0-@F.`.8);@
M9.&`X61Q`.#H@9WE!>`.X`?@CN'ES8S@!N">X`.`F.!E,8#A96$`X`PP`^#P
M<9WE9$&(X`8P@^%B*DSC[.V.X`0PD^!LP:#A[DV#X/AAG>4"<)?@93$LX```
ME^`.,"/@`S"0X`(`EN!E`8#@`&*=Y>1=@^!N,2S@!#`CX`,PD.!D0:#A`F"6
MX`S`EN!N`23@"&*=Y04`(.#E/8/@``"<X`+`EN!NP8S@$&*=Y>/M@.!E`23@
M`P`@X```G.!C,:#A`F"6X`1`EN!EP2/@&&*=Y0[`+.#N#8#@#,"4X`)`EN!E
M083@(&*=Y>!=C.!NP2/@`,`LX`S`E.!@`:#A`D"6X`-`E.`H8IWE;C$@X`4P
M(^#ES8S@`S"4X`)@EN#L38/@;N&&X&4Q(.`P8IWE##`CX`,PGN!LP:#A`N"6
MX`#@GN`X8IWE90$LX`0`(.#D/8/@``">X`+@EN!EX8[@0&*=Y>-=@.!D`2S@
M`P`@X```GN!C,:#A`N"6X`S@GN!(8IWE9,$CX`7`+.#E#8#@#,">X`+@EN!D
MX8[@4&*=Y>!-C.``<*#C9<$CX`#`+.`,P)[@8`&@X0+@EN`#X)[@6&*=Y64Q
M(.`$,"/@Y,V,X`,PGN`"X);@9>&.X&!BG>7L78/@9#$@X`PP(^`#,)[@;,&@
MX0+@EN``X)[@:&*=Y60!+.`%`"#@Y3V#X```GN`"X);@9.&.X'!BG>7C38#@
M90$LX`,`(.```)[@8S&@X0+@EN`,X)[@>&*=Y67!(^`$P"S@#,">X`+@EN#D
M#8#@9>&.X&1A(^"`4IWE`&`FX.#-C.`&X)[@8`&@X0)0E>`#,)7@9&$@X(A2
MG>4,8";@!C"3X`(@E>#L[8[@;+&+X`H@DN!LP2#@#L`LX&Z1B>!D(8+@#""2
MX!BP@>40D('E","1Y>X]@^`,P)/@XSV"X"`@D>4`,('E`@"0X#P@G^4T,)_E
M`B"/X`C`@>4@`('E)'"!Y0,PDN<`()/EE#*=Y0(@,^``,*#C`0``&J??C>+P
MC[WHBOO_ZWB1```@`0``1(4```'*H./P1RWI#,!-X.`/C.7(,)_E`(!0X@,P
MC^`K```*O""?Y0(PD^<`D)/E``!9XR@```H`4-CE`7"@X0``5>,]`%43`5"@
M$P!0H`,1```:`$"9Y0``5.,,```*"6"@X04@H.$($*#A!`"@X8_[_^L``%#C
M`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH"%"@X0$P]>4`
M`%/C/0!3$_O__QH(4$7@YO__Z@E@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'
MO>@(0*#A[?__Z@E`H.'K___J[(0``!P!```!RJ#C$$`MZ0S`3>"(#XSEC""?
MY8PPG^4"((_@<-!-X@,PDN<-$*#A`#"3Y6PPC>4`,*#C`$"@X4K[_^L``%#C
M``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`
M()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0@+WH`A"@XP0`H.'L^O_K$`]OX:`"
MH.'N___J)/O_ZP2$```@`0``N(,```'*H./P0"WI#,!-X'`/C.5@(9_E8#&?
MY0(@C^`#,)+G?-!-X@!04.(`,)/E=#"-Y0`PH.,"```*`##5Y0``4^,*```:
M-"&?Y2PQG^4"((_@`S"2YP`@D^5T,)WE`B`SX``PH.-"```:?-"-XO"`O>B;
M^O_K`&!0XO'__PH&`*#A'OO_ZP``4.,K```*$S#0Y1-`@.(N`%/C`@``&@$P
MU.4``%/C]/__"A,PT.4N`%/C)@``"@4`H.'(^O_K`'"@X00`H.'%^O_K`'"'
MX`)PA^('`*#AZ/K_ZP1`C>4`0*#AG#"?Y0<@H.$"$*#C`S"/X`!0C>4$^__K
M!`"@X0@0C>*G^O_K`0!PXP0`H.$#```*&#"=Y0\Z`^(!"5/C$@``"K'Z_^L$
M`*#AE/K_ZP8`H.'R^O_K``!0X]/__QH&`*#AP?K_ZP4`H.'7^O_KO/__Z@$P
MU.4N`%/CU?__&@(PU.4``%/CQ/__"M'__^JC___KZ___ZL/Z_^M4@P``(`$`
M`""#``",(P```<J@XQ!`+>D,P$W@Z`^,Y7!/'>YH()_E:!"?Y0(@C^`!()+G
M$-!-XEP`G^4,((WE``"?YU0PG^54$)_E``"4YP,PC^`!$(_@T_K_ZP#`H.-`
M`)_E0#"?Y0``G^<\()_E/!"?Y0,PC^```)3G`B"/X`@0C>@!$(_@</K_ZQ#0
MC>(0@+WHR($``!0!``#$@@``;&,``+0B``"<@@``I"4``)@:``"@(@```<J@
MX_!!+>D,P$W@``",Y2``#.4!<*#A`!&?Y0`QG^4!VDWB"-!-X@$0C^`#,)'G
M`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`C>+_+P#C"!"@X0``C^"8
M^O_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2XQ<``!H``%/C%```&G`/
M'>Z8,)_E!R"@X0,PG^<&$*#A`P"0YQ[Z_^N$()_E=#"?Y0(@C^`!&HWB`S"2
MYP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((T(WB\(&]Z`-`H.$$(*#A
M+Q"@XP@`H.&/^O_K``!0X^/__PIPSQWN,`"?Y00PH.$``)_G"""@X080H.$`
M`)SG,?K_Z^'__^I-^O_K%($``"`!```L(@``N($``)"```!(@0```<J@X_!/
M+>D,P$W@T`^,Y0%`H.$8(I_E&#*?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@
MXP`PT>4`4*#A/0!3XP%`@0($`*#A"OK_ZPT0H.$`8*#A!0"@X:C^_^O8<9_E
M`)!0X@=PC^!````*`?K_ZP``5N$W``":P#&?Y0"`G>4#<)?G"(&@X0`PU>4`
M`%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`
MAN(#`(#@`&"7Y1+Z_^L``%#C"`"&YQ4```H%`*#A`#"7Y0@0D^<!,-#D/0!3
MXP``4Q,`,,'E!@``"@$@@>(!,-#D`A"@X0``4^,]`%,3`3#"Y/G__QH],*#C
M`2"@X0`PP>4!,-3D``!3XP$PXN7[__\:$"&?Y0`QG^4"((_@`S"2YP`@D^4$
M,)WE`B`SX``PH.,W```:#-"-XO"/O>@!D$GB`3#4Y```4^,!,.GE^___&N[_
M_^K(,)_E`W"7YP"`E^4`,)CE``!3XR8```H(,*#A!""SY0D0H.$``%+C`9")
MXOK__QH#$('B`;&@X9@PG^4#,(_@`""3Y0``4N,0```:`2"@XPL`H.$`((/E
MT?G_ZP"@4.+5__\*"!"@X0F!H.$+,*#A"""@X??Y_^L`H(?E`#"@XP"0C>4!
MD(GB"3&*YZ'__^H+$*#A"`"@X?'Y_^L``%#C`*"@X0``A^7#__\*"8&@X?'_
M_^H#D*#A"+"@X]W__^JZ^?_KZ'\``"`!``"@?P``'`$``-!^``#<?P``<`\=
M[C0@G^4TP)_E`B"/X`P@DN<(T$WB*!"?Y00@C>4!$)_G(#"?Y0$`D.<<$)_E
M`S"/X`$0C^`(T(WBR_G_ZJQ]```4`0``J'X``%!?``"8'@```<J@X_!`+>D,
MP$W@``",Y0'*3.(``(SE,``,Y>`@G^7@,)_E`MI-XAS03>("((_@`S"2YP(:
MC>(4$('B`#"3Y0`P@>4`,*#CH?G_Z[C`G^6X,)_E`4J-X@S`C^`00(3B`1"-
MZ`$@`>,"$*#C!`"@X0,PC^`,8(WBH?G_ZP0`H.$!*J#C!A"@X9?Y_^L`0%#B
M`%"@LPH``+H!<(3B!P"@X7/Y_^L`4%#B!0``"@<PH.$&$*#A!""@X3KY_^L`
M,*#C!##%YT@@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@D^4`,)'E`B`SX``P
MH.,#```:!0"@X0+:C>(<T(WB\("]Z%[Y_^LX?0``(`$``'`>``!,'@``F'P`
M`+C__^H!RJ#C\$\MZ0S`3>```(SEJ``,Y43"G^5$(I_E0MU-X@303>(,P(_@
M`&"@X30"G^4"()SG03V-XA"`C>(!0*#A``"/X`@0H.$\,(/B`""2Y0`@@^4`
M(*#CN?W_ZR\0H.,`4*#A!@"@X>/X_^L``%#C$@``"O`!G^4&$*#A``"/X._^
M_^L&`*#AX"&?Y=`QG^4"((_@01V-X@,PDN<\$('B`""3Y0`PD>4"(#/@`#"@
MXVD``!I"W8WB!-"-XO"/O>@$`*#A&OG_ZZ01G^4!$(_@*?G_ZP!`4.+E__\*
M`##4Y9"1G^6`H(WB``!3XPF0C^`$<$KB.P``"@``5>,$```*!!"@X04`H.%.
M^?_K``!0XRL```H$`*#AY_C_ZP$P0.(#,(3@`P!4X0"PH.$`P*`S`#"$,`$0
MA#(#```Z"```Z@,`4>$`P,/E`@``"@$@<^4O`%+C^?__"@0`H.'6^/_K`+"@
MX08`H.'3^/_K"P"`X`$`@.(!"E#CO?__*O@`G^4),*#A``"/X`$JH.,"$*#C
M00"-Z0!`C>4'`*#A$?G_ZP@0H.$'`*#AM/C_ZP``4.,#```:8#`:Y0\Z`^("
M"5/C%0``"K00G^4``*#C`1"/X.GX_^L`0%#BI?__"@`PU.4``%/CP___&@``
M5>,6```*`##5Y2X`4^,#```*@$"?Y0&PH.,$0(_@U?__Z@$PU>4``%/CZO__
M"O?__^H!$*#C!P"@X9+X_^L``%#CY/__&E``G^4'$*#A``"/X(#^_^L'`*#A
MNOC_ZX[__^HX0)_E`;"@XP1`C^#!___JP/C_ZR1\```@`0``=!T``$0=``"X
M>P``!!T``.@<``!8'```!!P``*P;``"(&P``7!L```'*H.,00"WI#,!-X/@/
MC.4O$*#C`$"@X6+X_^L``%#C`4"`$@0`H.$00+WHG/C_Z@'*H.-P0"WI#,!-
MX```C.48``SE<"&?Y7`QG^4!VDWB`B"/X`C03>(!&HWB`S"2YP!@4.($$('B
M`#"3Y0`P@>4`,*#C+P``"@`PUN4``%/C+```"FCX_^L!((#B`0I2XP!`H.$X
M``"*!%"-X@80H.$%`*#A9OC_ZP$P1.(#,(7@!0!3X0<``)H`$*#C`@``Z@4`
M4^$!$,/E`@``"@$@4^0O`%+C^?__"B\0H.,%`*#A,/C_ZP``4.,E```*!0!0
MX0`PH(,`,,"%!0"@X6CX_^N\()_EM#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E
M`#"1Y0(@,^``,*#C(@``&@':C>((T(WB<("]Z(@@G^5\,)_E`B"/X`$:C>(#
M,)+G!!"!X@`@D^4`,)'E`B`SX``PH.,4```:8`"?Y0``C^`!VHWB"-"-XG!`
MO>A)^/_J``"@X][__^I$()_E,#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1
MY0(@,^``,*#C(`"?!0``CP#L__\*1?C_ZVAY```@`0``L'@``'AX``"X&0``
M+'@``'`9```!RJ#C<$`MZ0S`3>#H#XSEQ"2?Y<0TG^4"((_@P%2?Y0,PDN>\
M9)_E"-!-X@50C^``,)/E!#"-Y0`PH.,&8(_@#4"@X000H.$&`*#AHOS_ZP``
M4.,.```*C#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#
MX@0@D^4``%+C!""#Y/O__QKK___J5&2?Y09@C^`$$*#A!@"@X8S\_^L``%#C
M#@``"C0TG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($
M()/E``!2XP0@@^3[__\:Z___Z@!DG^4&8(_@!!"@X08`H.%V_/_K``!0XPX`
M``K<,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3
MY0``4N,$((/D^___&NO__^JL8Y_E!F"/X`00H.$&`*#A8/S_ZP``4.,.```*
MA#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4`
M`%+C!""#Y/O__QKK___J6&.?Y09@C^`$$*#A!@"@X4K\_^L``%#C#@``"BPS
MG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2
MXP0@@^3[__\:Z___Z@1CG^4&8(_@!!"@X08`H.$T_/_K``!0XPX```K4,I_E
M`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$
M((/D^___&NO__^JP8I_E!F"/X`00H.$&`*#A'OS_ZP``4.,.```*?#*?Y0`0
MG>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#
MY/O__QKK___J7&*?Y09@C^`$$*#A!@"@X0C\_^L``%#C#@``"B0RG^4`$)WE
M`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[
M__\:Z___Z@ABG^4&8(_@!!"@X08`H.'R^__K``!0XPX```K,,9_E`!"=Y0,P
ME><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___
M&NO__^JT89_E!F"/X`00H.$&`*#AW/O_ZP``4.,.```*=#&?Y0`0G>4#,)7G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___J8&&?Y09@C^`$$*#A!@"@X<;[_^L``%#C#@``"APQG^4`$)WE`S"5YP`@
MD^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___
MZ@P!G^4$$*#A``"/X+'[_^L`$%#B`@``"O@`G^4``(_@[/S_Z_``G^4$$*#A
M``"/X*C[_^L`$%#B`@``"MP`G^4``(_@X_S_Z]0`G^4$$*#A``"/X)_[_^L`
M$%#B$@``"L``G^4``(_@VOS_Z[@@G^5D,)_E`B"/X`,PDN<`()/E!#"=Y0(@
M,^``,*#C$```&I@0G^68`)_E`1"/X```C^`(T(WB<$"]Z,K\_^J$`)_E!!"@
MX0``C^"&^__K`!!0XNG__PIP`)_E``"/X,'\_^OE___J!_?_Z\AW```@`0``
MM'<``#P9```<`0``[!@``)P8``!0&````!@``+@7``#\%@``%!<``,@6``!\
M%@``J!4``-05``"H%0``Q!4``,05``#`%0``Y!0``&AS````%P```!4``&P5
M``#P%````<J@XP3@+>4,P$W@\`^,Y7@@G^5X,)_E`B"/X'0`G^4,T$WB`S"2
MYPT0H.$``(_@`#"3Y00PC>4`,*#C5?O_ZP``4.,%```*``#0Y0``4.,P`%`3
M`0"@`P``H!,!`"#B-""?Y2@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,!
M```:#-"-X@3PG>3)]O_KA'(``"`!``!,%```-'(```'*H.,/`"WI!.`MY0S`
M3>#P#XSE2""?Y4@PG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.,P`)_E,,"?
MY10PC>(``(_@`#"-Y0P`D.<"$*#C$""=Y0``D.66]O_K_P"@X^CV_^O@<0``
M(`$``+QQ```D`0```,"@X_!'+>D!Z*#C#,!-X`[@3.`!RDSB``",Y0X`7.'[
M__\:.``.Y0(0H.-XX9_E>,&?Y0'83>(8T$WB#N"/X`S`GN<!2(WB`""@XP`P
MH.,`P)SE%,"$Y0#`H.,`$(WE`("@X8CV_^L!`%#B`'#!XL<OH.''/R#@`C!3
MX',P_^8","/@`C!3X`(@PN`#8%#@`G#'X```5^,40(3B.```N@B0H.,,4(WB
M`9!`XP`0H.,&(*#A!S"@X0@`H.$`$(WE<?;_ZP$`<>,!`'`#,@``"@D@H.$%
M$*#A"`"@X3'V_^L!`'#C*0``"@<`4.,?``":"`!`X@!`E>`<```JL*"?Y0J@
MC^`"``#J`4!$X@4`5.$6```Z"""@XPH0H.$$`*#A^?7_ZP``4./V__\:!4!$
MX`8`E.#$'Z?@>""?Y6PPG^4"((_@`<B-X@,PDN<4P(SB`""3Y0`PG.4"(#/@
M`#"@XQ```!H!V(WB&-"-XO"'O>@!:%;B`'#'X@$`=^,!"'8#R?__&@``X.,`
M$*#AZ?__ZB0`G^4``(_@>___ZQP`G^4``(_@>/__ZSWV_^M,<0``(`$``,AQ
M``!(<```7!(``$`2```!RJ#C$$`MZ0S`3>#X#XSE[?7_ZQ#V_^L``%#C``"0
M%1"`O>@!RJ#C\$`MZ0S`3>#0#XSE/"&?Y3QAG^4\,9_E`B"/X!S03>(#,)+G
M!F"/X`!0H.$0$(WB!@"@X0`PD^44,(WE`#"@XY3Z_^L`0%#B`@``"@`PU.4`
M`%/C#@``&OP@G^7T,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C,P``&@40
MH.'8`)_E``"/X!S0C>+P0+WHP/O_Z@40H.'Q]?_K``!0XPH```JX()_EJ#"?
MY0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XR```!H<T(WB\("]Z`4`H.'-]?_K
M`'"@X00`H.'*]?_K`'"'X`)PA^('`*#A[?7_ZVP0G^5L,)_E`1"/X`<@H.$(
M0(WE`S"/X`00C>4`4(WE`A"@XP!`H.$&]O_K2""?Y2PPG^4"((_@`S"2YP`@
MD^44,)WE`B`SX``PH.,$$*`!!@"@`<[__PK9]?_KA&\``.P1```@`0``/&\`
M`(P1``#P;@``*!```"`0``!T;@```<J@X_!/+>D,P$W@X`Z,Y;3FG^7\T$WB
M#N"/X+!`C>(@X(WE!."@X:`6G^6@QI_EH":?Y0$0C^`"()'G#,"/X`PPC.(8
M8(SBI'"-X@`@DN7T((WE`""@XQP`C>4'`)/H!P"'Z`\`MN@/`*[H`P"6Z##`
MC.*84(WB`P".Z`<`G.@'`(7H4`:?Y2B`C>(($*#A``"/X"+Z_^L`8%#B`@``
M"@`PUN4``%/C*0$`&E_U_^N"]?_K``!0XX@```H`8)#E``!6XX4```H&`*#A
M<O7_ZX`@H.$!L(+B"P"@X97U_^L`P-;E`%"@X0``7.,+D*`1)`"-%20!``K@
MI9_E"J"/X`L@H.$*,*#A`A"@XP4`H.$`P(WEJ_7_ZPL`6>$)(*`A"R"@,0(P
M2^(+$$+@`<#VY0(P0^`"$('B`@!1X0&P@R`"L(,P``!<XP)0A>+K__\:C`6?
MY0``C^`"``#J!`"TY0``4.,-```*"!"@X>SY_^L`4%#B^/__"@`PU>4``%/C
M]?__"B#Z_^L``%#C\O__"@4`H.%>]?_K`$!0X@T``!H$0)?D``!4XPH```H`
M,-3E``!3X],```H$`*#A$OK_ZP``4./U__\*!`"@X5#U_^L`0%#B\?__"@0`
MH.$N]?_K)%"=Y0!@H.$%`*#A*O7_ZP!@AN`!:X;B!&"&X@8`H.%,]?_K`'"@
MX=@TG^4&(*#A`S"/X`@PC>7,-)_E`A"@XP,PC^`$,(WEP#2?Y0Q0C>4#,(_@
M`$"-Y6+U_^L'':#C!P"@X<ST_^L!`'#C`P``&GKU_^L``)#E$0!0XZ\``!H(
M$*#A!P"@X4'U_^L`0%#B,0``"G@$G^4@P)WE'#"=Y0``G.=L))_E`#"3Y0!P
MC>4"$*#C``"0Y0(@C^`K]?_K`%"@XU`DG^4H-)_E`B"/X`,PDN<`()/E]#"=
MY0(@,^``,*#C_```&@4`H.'\T(WB\(^]Z`[U_^L`8%#BBP``&@0`E>0``%#C
M"0``"@@0H.&+^?_K`#!0XOC__PH`,-/E``!3X_+__QH$`)7D``!0X_7__QH-
M`*#C!O7_ZPV0H./88Y_E4\"@XP!0H.$)L*#A!F"/X"0`C>5N___J.#"=Y0\Z
M`^(!"5/CR?__&D!0G>6V]/_K``!5X<7__QHX,)WE4S#HYP<-4^/!__\:!@"@
MX?#T_^L`4*#AA`.?Y0@0H.$``(_@9OG_ZP`04.*````*'#"=Y0``D^60^__K
M`*!0XGL```H*`*#AN_3_ZP,`4.,`D*#A#```FD@3G^4$`$#B``"*X`$0C^`6
M]?_K``!0XP4``!H$`%GCIP``"@F0BN`%,%GE+P!3XZ,```H8`Y_E"!"@X0``
MC^!)^?_K``!0XP,```H`,-#E,`!3XP``4Q,$```:"@"@X0`0H..M]/_K`(!0
MXET``!K@$I_EX`*?Y0$0C^```(_@>?K_Z]7T_^O0,I_ET"*?Y0,PC^`$,(WE
MR#*?Y0(@C^#$HI_EQ)*?Y<2"G^4(`(WE#""-Y0(0H.,&(*#A!0"@X0!PC>4#
M,(_@T/3_ZPJ@C^`)D(_@"("/X`X``.KI]/_K`#"0Y1$`4^,/```:N_3_ZP#`
MH.$!0(3B`A"@XPHPH.$&(*#A!0"@X8`1C>@0D(WE#$"-Y;WT_^L'':#C!0"@
MX2?T_^L!`'#CZ___"@<`H.%3]/_K/`*?Y040H.$``(_@2?K_ZP4`H.%@_O_K
M9O__Z@-`H.$Q___J8?3_ZX`@H.$!L(+B[?[_ZB`0G>7((9_E'#"=Y0+`D>?\
M(9_E`#"3Y00`C>4``)SE`A"@XP(@C^``<(WE?_3_ZU+__^I+_O_KV"&?Y70Q
MG^4"((_@`S"2YP`@D^7T,)WE`B`SX``PH.-/```:!@"@X?S0C>+P3[WH8?3_
MZB0`C>7N_O_J'#"=Y0"@D^6`___JOOW_ZP"@4>(`D*#AG?__N@"PH.,*(%#B
M`##*X@@`H.$`L(WE6/3_ZY`0C>(&(*#C"`"@X1P0C>4:]/_K!@!0XQP0G>4U
M```:0SR@XY`@G>5!,T3C`P!2X8K__QI(-03CM"#1X0,`4N&&__\:,B!9X@`P
MRN((`*#A`+"-Y<A`C>)!]/_K*""@XP@`H.$$$*#A!/3_ZR@`4.,@```:^#"?
MY?@0G^4#,(_@!#"-Y?`PG^4!$(_@#!"-Y08@H.$"$*#C!0"@X0A`C>4`<(WE
M`S"/X/"PS>53]/_KF?__ZAPPG>4$D)/E``!9XU?__PH)`*#A`?3_ZP,`4.-3
M__^:I!"?Y00`0.(``(G@`1"/X%WT_^L``%#C":"@`4O__^H@]/_KA`"?Y0``
MC^!7_?_K$&X``/1M```L;P``(`$```0/``"X#P``_`X``+@.``"<#0``C`X`
M`"0!``!T#@``?&L``'P-``#@#0``I`T``!`,``"T#0``T`L``'0+``#X#0``
M&`T``"`-``#$#0``,`L``*`*``","P``R&@``'@)``#\"P``&`L``,@*``"T
M"@```<J@XW!`+>D,P$W@Z`^,Y5PBG^5<,I_E`B"/X`,PDN<(T$WB`#"3Y00P
MC>4`,*#C<$\=[@U@H.$\,I_E/`*?Y0,PG^<&$*#A`U"4YP``C^!H,-7E:3#%
MY5WX_^L``%#C`@``"@`PT.4Q`%/C90``"J#[_^L(,I_E`S"?YP-0E.<`$I_E
M!0"@X0,PH.,!(*#C`1"/X(+S_^L`4%#B#```"A`@E>7@,9_E`!"2Y0,PG^?8
M(9_E`P"4YP(@C^!^\__K$#"5Y0`0D^4(,)'E`043XU@``!JX$9_E`S"@XP$0
MG^<!(*#C`0"4YZ@1G^4!$(_@:_/_ZP!04.(+```*F`&?Y080H.$``(_@,?C_
MZP`@4.)````*A#&?Y1`0E>4#,)_G`!"1Y0,`E.=C\__K<#&?Y7`1G^4#,)_G
M`2"@XP-0E.<!$(_@!0"@X4;S_^M8(9_E`!"@X0(@C^`%`*#A5O/_ZP`@H.-$
M,9_E1`&?Y0,PG^<&$*#A`S"4YP``C^!I(,/E$_C_ZRQ1G^4``%#C!5"/X`!`
MH.$(`(7E$0``"@<=H.,$`*#A(//_ZP$P@.(1`%#C`0!3$R4``(K\()_EM#"?
MY0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>6P_?_K
M``!0XP!`H.$(`(7EY___&KP`G^4``(_@C//_ZP$PT.4``%/CFO__"I7__^JD
M,)_E$""5Y0,PC^`$,)/E``"2Y0`0D^79^/_KO/__ZH@PG^4#,)_G`P"4YV'S
M_^NA___J://_ZW00G^4`,*#A`1"/X&P`G^4$$)'E!""@X0`0D>4``(_@<?/_
MZ\!F```@`0``J&<``$P(``!P9P``V`D``#QG``"T"0``#&<``(@)``!,!P``
MS&8``+1F```X"0``/`D``'QF``#,!@``T&8``!AE``"8"```/&8``*QE```$
M9@``4`@```'*H.,P0"WI#,!-X.@/C.4,(9_E##&?Y0(@C^``0*#A!`&?Y0,P
MDN<,T$WB#1"@X0``C^``,)/E!#"-Y0`PH..N]__K`#!0X@H```H`,-/E``!3
MXS``4Q,!,*`#`#"@$P$P(^(``%3C`#"@`P$P`Q(``%/C"@``&K`@G^6D,)_E
M`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C(```&@S0C>(P@+WH`##4Y0``4^/Q
M__\*!`"@X7#Z_^LO$*#C`%"@X<OR_^L``%#C`5"`$@4`H.$&\__K6!"?Y00@
MH.,!$(_@,O/_ZP``4./B__\:1""?Y3`PG^4"((_@`S"2YP`@D^4$,)WE`B`S
MX``PH.,#```:!`"@X0S0C>(P0+WHW??_ZO[R_^OL8P``(`$``+`%``"$8P``
MR`4``!!C```!RJ#C$$`MZ0S`3>#X#XSE@`"@X^_R_^L.>Y_M`'N`[0Y[G^T"
M>X#M#GN?[01[@.T.>Y_M!GN`[0Y[G^T`(*#C"'N`[0U[G^UX((#E"GN`[0Q[
M@.T0@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````
M`````````````<J@X_!'+>D,P$W@X`^,Y0*0H.$`,*#C`%"@X2C@D.4L`)#E
MB<&.X`X`7.$``-/@`4"@X3`@E>4T$)7ER0^@X0$``"H!()+B`!"AXBPPA>6I
M/J#A@#&#X0(PD^"@'J'@>`"5Y2C`A>4``%#C,#"%Y300A>4X@(4"(0``&C\`
M6>,Q``#:0)!)XBECH.$!<(;B!W.$X`@PH.$$$*#A0$"$X@#@D>4$P)'E"`"1
MY0P@D>40$('B!`!1X0#@@^4$P(/E"`"#Y0P@@^40,(/B\___&@%`H.$%`*#A
M]//_ZP<`5.'K__\:!FUFX`:3B>`)(*#A!Q"@X0@`H.%S\O_K>)"%Y?"'O>A`
M<&#B"0!7X0EPH*$X@(7B!!"@X0<@H.$``(C@:?+_ZW@PE>4#,(?@0`!3XW@P
MA>7PA[T8!0"@X0>02>`'0(3@V?/_Z\O__^H$<*#AY?__Z@'*H./P02WI#,!-
MX.@/C.5_(.#C*#"1Y3!@D>4SC[_FTS'EYP'`@^(X<('B.`!<XP%`H.$`4*#A
M-F^_Y@,@Q^<]``#:`!"@XT`@;.(,`(?@&_+_ZP0`H.&_\__K.""@XP`0H.,'
M`*#A%?+_ZP0`H.%P8(3E=("$Y;?S_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`P
ME.4C-*#A`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%
MY0@PE.4',,7E$S#4Y0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E
M&S#4Y0PPQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R
M,M3A$3#%Y2`PE.4C-*#A$C#%Y2`PE.43,,7E\$&]Z/#Q_^H`$*#C#`"'X#@@
M;.+=\?_KQO__Z@@PG^4#,(_@`#"3Y3CR_^K48```"$`MZ0B`O>@!``(`/@``
M`$$````,````00```!$```!!````)P```$$````V````00````,```!!````
M!@```$$````5````00````\```!!````#@```$$````F````00```!,```!!
M````*0```$$````"````00```!D```!!````"@```$$````+````00``````
M````````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O<V5L9B]E>&4``"]P<F]C+R5I
M+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E
M<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%
M4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@``
M`%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````
M4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@````!L<V5E:R!F86EL960`````<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E
M<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R````
M`'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````
M)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K
M97(Z.E9%4E-)3TX`````,2XP-C$```!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C
M86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD
M8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<
M,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM
M>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D
M8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O
M9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D
M<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C
M:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*
M<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P
M+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@
M,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]
M("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H
M*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P
M87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U
M=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@
M9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S
M="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&
M2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@
M;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O
M<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D
M(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<
M,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H
M92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE
M(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%
M7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD[
M"F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M
M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&
M2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N
M+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R
M;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A
M;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F
M:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN
M9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]
M("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@
M;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO
M=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R
M(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P
M87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T[
M"FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES
M(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,[
M"F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M
M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD
M969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L
M;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L
M("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U
M="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E
M("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R
M:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*
M:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I
M.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D
M;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z
M("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z
M:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M
M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D
M4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS
M92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B
M73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY
M("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T
M:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L
M("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A
M8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H
M(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A
M8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP
M<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!
M3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!54T52`````%5315).04U%`````%1%
M35!$25(`5$U0`"]T;7``````<&5R;'AS:2YC`````$-!0TA%```^````00``
M``P```!!````$0```$$````G````00```#8```!!`````P```$$````&````
M00```!4```!!````#P```$$````.````00```"8```!!````$P```$$````I
M````00````(```!!````&0```$$````*````00````L```!!````````````
M``"!L@&!L+"L!P````"&L@&!L+"K#P````"@L@&!L+"O!P````"!L@&!L+"J
M!P````"$`@&!L`^Q``````"%L@&!L+"N?P````!TA_]_L*H)@#2*_W\!````
MI(O_?Z\FLH`HF/]_L+"N@`B9_W^PJ!N`L)G_?["K'H`PF_]_L*@#@-";_W]\
M__]_`)W_?["O`H!$G_]_L+`!@)"?_W]P__]_H*#_?["PL("<H/]_;/__?R2C
M_W^PL*B`3*/_?VC__W_LI/]_L*H!@"BJ_W\`A`*`P*K_?US__W\LJ_]_8/__
M?^BL_W^PL*B`!*W_?["K!H!TKO]_L*\^@+RU_W^PJ@&`B+C_?["I`H"\N?]_
ML+"H@#RZ_W^PL*Z`B+O_?["PK(#0O/]_L+"P@-R\_W\!````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````H'0``M!P```$```!2
M`P```0```%T#```!````9P,```$```![`P``'0````,%```,````]!4```T`
M```X3P``&0```*"M```;````!````!H```"DK0``'`````0````$````M`$`
M`/7^_V_P!```!0```)P,```&````W`4```H````^!0``"P```!`````5````
M``````,```#(K@```@```.@!```4````$0```!<````,%```$0```#03```2
M````V````!,````(````'@````@```#[__]O`0``"/[__V^T$@``____;P,`
M``#P__]OVA$``/K__V\.````````````````````````````````````````
M`````````````````*BM```````````````6````%@```!8````6````%@``
M`!8````6````%@```!8````6````%@```!8````6````%@```!8````6````
M%@```!8````6````%@```!8````6````%@```!8````6````%@```!8````6
M````%@```!8````6````%@```!8````6````%@```!8````6````%@```!8`
M```6````%@```!8````6````%@```!8````6````%@```!8````6````%@``
M`!8````6````%@```!8````6````%@```!8````6````%@```!8````6````
M````````````````````````````````````````````````````````````
M````````\!@````````$L```"E!!4BYP;0H`````B)```#!0````````\%``
M`/10``!\D```.%```(20````````:)```'"0````````^%(``$=#0SH@*%-5
M4T4@3&EN=7@I(#$S+C(N,2`R,#(T,#$R-2!;<F5V:7-I;VX@9F,W9#@W93!F
M9F%D8V$T.6)E8S(Y8C(Q,#=C,65F9#!D839B-F1E9%T`03(```!A96%B:0`!
M*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+D%232YE>'1A8@`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!D`
M``````````````$`````````$P````<````"````<`$``'`!```D````````
M```````$`````````"8````'`````@```)0!``"4`0``(```````````````
M!``````````X````!0````(```"T`0``M`$``#P#```&``````````0````$
M````-````/;__V\"````\`0``/`$``#L````!@`````````$````!````#X`
M```+`````@```-P%``#<!0``P`8```<````#````!````!````!&`````P``
M``(```"<#```G`P``#X%``````````````$`````````3@```/___V\"````
MVA$``-H1``#8````!@`````````"`````@```%L```#^__]O`@```+02``"T
M$@``@`````<````#````!`````````!J````"0````(````T$P``-!,``-@`
M```&``````````0````(````<P````D```!"````#!0```P4``#H`0``!@``
M`!<````$````"````'P````!````!@```/05``#T%0``#```````````````
M!`````````!W`````0````8`````%@```!8``/`"``````````````0````$
M````@@````$````&````\!@``/`8``!(-@`````````````(`````````(@`
M```!````!@```#A/```X3P``"```````````````!`````````".`````0``
M``(```!`3P``0$\``/1!``````````````0`````````E@````$````"````
M-)$``#21``!(```````````````$`````````*$````!``!P@@```'R1``!\
MD0``Z`````X`````````!`````````"L`````0````(```!DD@``9)(```0`
M``````````````0`````````M@````X````#````H*T``*"=```$````````
M```````$````!````,(````/`````P```*2M``"DG0``!```````````````
M!`````0```#.````!@````,```"HK0``J)T``"`!```'``````````0````(
M````UP````$````#````R*X``,B>```X`0`````````````$````!````-P`
M```!`````P````"P````H```2```````````````!`````````#B````"```
M``,```!(L```2*```!0```````````````0`````````YP````$````P````
M`````$B@``!6```````````````!`````0```/`````#``!P``````````">
MH```,P```````````````0`````````!`````P``````````````T:`````!
2``````````````$`````````
